==> am_mod_lbr_0_3.zip: am_mod_lbr_0_3/components/lbr/language/1/barnraiser_01/overview.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once('inc/lbr_common.inc.php');

// HEADERS
$lang['hdr_latest_sets'] = 						"latest wiki-sets";
$lang['hdr_my_sets'] = 							"wiki-sets I am a contributor to";
$lang['hdr_latest_revisions'] = 				"latest revisions";
$lang['hdr_favourites'] = 						"bookmarked";
$lang['hdr_tied_revisions'] = 					"revisions from respected network";
$lang['hdr_tied_comments'] = 					"latest comments from respected network";


// ERRORS
$lang['err_no_tied_revisions'] = 				"You do not have any respected wiki-set contributors. You can apply respect to someone by clicking 'respect' above a page that they have revised. Once you show them respect their latest revision will appear here.";
$lang['err_no_tied_comments'] = 				"You do not have any respected wiki-set contributors. You can apply respect to someone by clicking 'respect' above a page that they have revised. Once you show them respect their latest comments will appear here.";
$lang['err_no_bookmarks'] = 					"You do not have any bookmarked wiki pages. You can add a bookmark by clicking the bookmark icon SYS_KEYWORD_ICON above a page revision.";


// BODY TEXTS
$lang['txt_no_revisions'] = 					"no revisions yet";

?>

==> am_mod_lbr_0_5.zip: am_mod_lbr_0_5/components/lbr/language/1/barnraiser_01/overview.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once('inc/lbr_common.inc.php');

// HEADERS
$lang['hdr_latest_sets'] = 						"latest wiki-sets";
$lang['hdr_my_sets'] = 							"wiki-sets I am a contributor to";
$lang['hdr_latest_revisions'] = 				"latest revisions";
$lang['hdr_favourites'] = 						"bookmarked";
$lang['hdr_tied_revisions'] = 					"revisions from respected network";
$lang['hdr_tied_comments'] = 					"latest comments from respected network";


// ERRORS
$lang['err_no_tied_revisions'] = 				"You do not have any respected wiki-set contributors. You can apply respect to someone by clicking 'respect' above a page that they have revised. Once you show them respect their latest revision will appear here.";
$lang['err_no_tied_comments'] = 				"You do not have any respected wiki-set contributors. You can apply respect to someone by clicking 'respect' above a page that they have revised. Once you show them respect their latest comments will appear here.";
$lang['err_no_bookmarks'] = 					"You do not have any bookmarked wiki pages. You can add a bookmark by clicking the bookmark icon SYS_KEYWORD_ICON above a page revision.";


// TEXTS
$lang['txt_more'] = 							"more";

?>
